# PythonModules
### Inside of here you will find all of our fascinating pyhton modules! Please do not copy or pirate any of our work. Some of our modules may take extremely long.


### Current Module: discordus.py
#### This module will offer a **simpler** way, rather then using discord.py, extremely easy to use.